@@ -7,7 +7,7 @@
 ;;              Theodor Thornhill <theo@thornhill.no>
 ;; Created    : September 2020
 ;; Modified   : 2020
-;; Version    : 1.1.0
+;; Version    : 1.1.1
 ;; Keywords   : c# languages oop mode
 ;; X-URL      : https://github.com/emacs-csharp/csharp-mode
 ;; Package-Requires: ((emacs "26.1"))
@@ -96,18 +96,15 @@
   csharp ?@)
 
 (c-lang-defconst c-ml-string-opener-re
-  ;; "\\(?:\\=\\|[^\"]\\)\\(?:\"\"\\)*\\(\\(\"\\)\\)\\(?:[^\"]\\|\\'\\)"
+  ;; "\\(\\(?:@\\$?\\)\\(\"\\)\\)"
   csharp
   (rx
-   (seq
-    (or point (not (any "\"")))
-    (zero-or-more "\"\"")
-    (group
-     (group "\""))
-    (or (not (any "\"")) eos))))
+   (group
+    (or "@" "@$")
+    (group "\""))))
 
 (c-lang-defconst c-ml-string-max-opener-len
-  csharp 2)
+  csharp 3)
 
 (c-lang-defconst c-ml-string-max-closer-len
   csharp 2)
@@ -123,13 +120,12 @@
     (or (not (any "\"")) eos))))
 
 (c-lang-defconst c-ml-string-back-closer-re
-  ;; "\\(:?\\`\\|[^\"]\\)\"*"
+  ;; "\\(?:\\`\\|[^\"]\\)\"*"
   csharp
   (rx
    (seq
-    (group
-     (or (seq (opt ":") bos)
-         (not (any "\""))))
+    (or bos
+        (not (any "\"")))
     (zero-or-more "\""))))
 
 (c-lang-defconst c-type-prefix-kwds
